var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, copyDefault, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && (copyDefault || key !== "default"))
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toCommonJS = /* @__PURE__ */ ((cache) => {
  return (module2, temp) => {
    return cache && cache.get(module2) || (temp = __reExport(__markAsModule({}), module2, 1), cache && cache.set(module2, temp), temp);
  };
})(typeof WeakMap !== "undefined" ? /* @__PURE__ */ new WeakMap() : 0);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  BadRequestException: () => BadRequestException,
  HttpException: () => HttpException,
  InternalServerErrorException: () => InternalServerErrorException,
  MethodNotAllowedException: () => MethodNotAllowedException,
  NotFoundException: () => NotFoundException,
  UnauthorizedException: () => UnauthorizedException,
  withExceptionHandling: () => withExceptionHandling2
});

// src/http-exceptions.ts
var HttpException = class extends Error {
  constructor(status, metadata, options) {
    super(metadata.message);
    this.status = status;
    this.metadata = metadata;
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this, this.constructor);
    }
    this.options = options != null ? options : { json: true };
  }
  toString() {
    return `HttpException: ${this.status}, ${this.metadata.message} (${this.metadata.type})`;
  }
};
var BadRequestException = class extends HttpException {
  constructor(metadata, options) {
    super(400, metadata, options);
    this.metadata = metadata;
  }
};
var UnauthorizedException = class extends HttpException {
  constructor(metadata, options) {
    super(401, metadata, options);
    this.metadata = metadata;
  }
};
var NotFoundException = class extends HttpException {
  constructor(metadata, options) {
    super(404, metadata, options);
    this.metadata = metadata;
  }
};
var MethodNotAllowedException = class extends HttpException {
  constructor(metadata, options) {
    super(405, metadata, options);
    this.metadata = metadata;
  }
};
var InternalServerErrorException = class extends HttpException {
  constructor(metadata, options) {
    super(500, metadata, options);
    this.metadata = metadata;
  }
};

// src/with-exception-handling.ts
var withExceptionHandling = (options = {}) => (next) => async (req, res) => {
  try {
    await next(req, res);
  } catch (error) {
    const shouldIncludeErrorContext = options.shouldIncludeErrorContext ? options.shouldIncludeErrorContext(req) : false;
    const errorContext = options.getAdditionalErrorContext ? options.getAdditionalErrorContext(req) : {};
    if (error instanceof Error) {
      errorContext.stack = error.stack;
    }
    if (error instanceof HttpException) {
      if (error.options.json) {
        res.status(error.status).json({
          error: __spreadValues(__spreadValues({}, error.metadata), shouldIncludeErrorContext ? errorContext : {})
        });
        return;
      } else {
        res.status(error.status).end(error.metadata.message);
        return;
      }
    } else {
      const formattedError = new HttpException(500, {
        type: "internal_server_error",
        message: error instanceof Error ? error.message : "Unknown error"
      });
      res.status(500).json({
        error: __spreadValues(__spreadValues({}, formattedError.metadata), shouldIncludeErrorContext ? errorContext : {})
      });
      return;
    }
  }
};
var with_exception_handling_default = withExceptionHandling;

// src/with-ok-status.ts
var withOkStatus = (options = {}) => (next) => async (req, res) => {
  const originalJson = res.json;
  res.json = function(data) {
    const ok = res.statusCode >= 200 && res.statusCode < 300;
    const shouldIncludeStatus = options.addIf ? options.addIf(req) : true;
    if (shouldIncludeStatus) {
      originalJson.call(this, __spreadProps(__spreadValues({}, data), {
        ok
      }));
    } else {
      originalJson.call(this, data);
    }
  };
  await next(req, res);
};
var with_ok_status_default = withOkStatus;

// src/index.ts
var withExceptionHandling2 = ({
  addOkStatus = false,
  okStatusOptions,
  exceptionHandlingOptions
} = {}) => (next) => (req, res) => {
  if (addOkStatus) {
    return with_ok_status_default(okStatusOptions)(with_exception_handling_default(exceptionHandlingOptions)(next))(req, res);
  }
  return with_exception_handling_default(exceptionHandlingOptions)(next)(req, res);
};
module.exports = __toCommonJS(src_exports);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  BadRequestException,
  HttpException,
  InternalServerErrorException,
  MethodNotAllowedException,
  NotFoundException,
  UnauthorizedException,
  withExceptionHandling
});
//# sourceMappingURL=index.js.map